#include "obstacle.h"
#include <stdlib.h>
#include "snake.h"
#include "game.h"
#include "food.h"

void InitObstacles(Obstacle obstacles[], int count) {
    for (int i = 0; i < count; i++) {
        obstacles[i].active = false;
    }
}

void SpawnObstacle(Obstacle obstacles[], int count, const Snake *snake, const Food *food) {
    for (int i = 0; i < count; i++) {
        if (!obstacles[i].active) {
            Vector2 newPos;
            bool validPosition = false;
            
            // Keep trying until we find a valid position
            while (!validPosition) {
                validPosition = true;
                newPos = (Vector2){
                    rand() % (SCREEN_WIDTH / CELL_SIZE),
                    rand() % (SCREEN_HEIGHT / CELL_SIZE)
                };
                
                // Check if position overlaps with snake
                for (int j = 0; j < snake->length; j++) {
                    if (newPos.x == snake->segments[j].x && newPos.y == snake->segments[j].y) {
                        validPosition = false;
                        break;
                    }
                }
                
                // Check if position overlaps with food
                if (newPos.x == food->position.x && newPos.y == food->position.y) {
                    validPosition = false;
                }
                
                // Check if position overlaps with other obstacles
                for (int j = 0; j < count; j++) {
                    if (obstacles[j].active && 
                        newPos.x == obstacles[j].position.x && 
                        newPos.y == obstacles[j].position.y) {
                        validPosition = false;
                        break;
                    }
                }
            }
            
            obstacles[i].position = newPos;
            obstacles[i].active = true;
            break;
        }
    }
}
// renders obstacles as gray squares with an X detail.
void DrawObstacles(const Obstacle obstacles[], int count) {
    for (int i = 0; i < MAX_OBSTACLES; i++) {
        if (obstacles[i].active) {
            // Main rock shape
            DrawRectangle(obstacles[i].position.x * CELL_SIZE,
                         obstacles[i].position.y * CELL_SIZE,
                         CELL_SIZE, CELL_SIZE, GRAY);
            // Rock details
            DrawLine(obstacles[i].position.x * CELL_SIZE + 2,
                    obstacles[i].position.y * CELL_SIZE + 2,
                    obstacles[i].position.x * CELL_SIZE + CELL_SIZE - 2,
                    obstacles[i].position.y * CELL_SIZE + CELL_SIZE - 2,
                    DARKGRAY);
            DrawLine(obstacles[i].position.x * CELL_SIZE + CELL_SIZE - 2,
                    obstacles[i].position.y * CELL_SIZE + 2,
                    obstacles[i].position.x * CELL_SIZE + 2,
                    obstacles[i].position.y * CELL_SIZE + CELL_SIZE - 2,
                    DARKGRAY);
        }
    }
}
// checks collision with obstacle, if snakes head x, y is in the same position as obstacle return True, if not return false.
bool CheckObstacleCollision(const Snake *snake, const Obstacle obstacles[], int count) {
  Position head = snake->segments[0];  
  for (int i = 0; i < count; i++) {
      if (obstacles[i].active && 
          head.x == obstacles[i].position.x && 
          head.y == obstacles[i].position.y) {
          return true;
      }
  }
  return false;
}